@@ -22,6 +22,7 @@ if platform.system() == "Windows":
                 if p and glob.glob(os.path.join(p, "gdal*.dll")):
                     os.add_dll_directory(os.path.abspath(p))
 
+from rasterio._base import DatasetBase
 from rasterio._io import Statistics
 from rasterio._vsiopener import _opener_registration
 from rasterio._show_versions import show_versions
@@ -81,7 +82,7 @@ except ImportError:
     have_vsi_plugin = False
 
 __all__ = ['band', 'open', 'pad', 'Band', 'Env', 'CRS']
-__version__ = "1.4.1"
+__version__ = "1.4.4"
 __gdal_version__ = gdal_version()
 __proj_version__ = ".".join([str(version) for version in get_proj_version()])
 __geos_version__ = ".".join([str(version) for version in get_geos_version()])
@@ -241,7 +242,7 @@ def open(
             or hasattr(fp, "read")
             or hasattr(fp, "write")
             or isinstance(fp, (os.PathLike, MemoryFile, FilePath))
-        ):
+        ) or isinstance(fp, DatasetBase):
             raise TypeError(f"invalid path or file: {fp!r}")
     if not isinstance(mode, str):
         raise TypeError(f"invalid mode: {mode!r}")
