@@ -91,7 +91,7 @@ def calc(ctx, command, files, output, driver, name, dtype, masked, overwrite, me
           the limits of the dataset's natural data type.
         * (take foo j) evaluates to the j-th band of a dataset named foo
           (see help on the --name option above).
-        * Standard numpy array operators (+, -, *, /) are available.
+        * Standard numpy array operators (+, -, \*, /) are available.
         * When the final result is a list of arrays, a multiple band
           output file is written.
         * When the final result is a single array, a single band output
@@ -113,7 +113,7 @@ def calc(ctx, command, files, output, driver, name, dtype, masked, overwrite, me
     The command above produces a 3-band RGB GeoTIFF, with red levels
     incremented by 125, from the single-band input.
 
-    The maximum amount of memory used to perform caculations defaults to
+    The maximum amount of memory used to perform calculations defaults to
     64 MB. This number can be increased to improve speed of calculation.
 
     """
