@@ -1,4 +1,4 @@
-"""$ rio merge"""
+"""The rio merge CLI command."""
 
 import warnings
 
@@ -8,13 +8,15 @@ from rasterio.enums import Resampling
 from rasterio.errors import RasterioDeprecationWarning
 from rasterio.rio import options
 from rasterio.rio.helpers import resolve_inout
+from rasterio.merge import MERGE_METHODS
 
 
-def deprecated_precision(*args):
-    warnings.warn(
-        "The --precision option is unused, deprecated, and will be removed in 2.0.0.",
-        RasterioDeprecationWarning,
-    )
+def deprecated_precision(ctx, param, value):
+    if value is not None:
+        warnings.warn(
+            "The --precision option is unused, deprecated, and will be removed in 2.0.0.",
+            RasterioDeprecationWarning,
+        )
     return None
 
 
@@ -28,6 +30,10 @@ def deprecated_precision(*args):
               type=click.Choice([r.name for r in Resampling if r.value <= 7]),
               default='nearest', help="Resampling method.",
               show_default=True)
+@click.option('--method',
+              type=click.Choice(list(MERGE_METHODS)),
+              default='first', help="Merging strategy.",
+              show_default=True)
 @options.nodata_opt
 @options.dtype_opt
 @options.bidx_mult_opt
@@ -39,6 +45,22 @@ def deprecated_precision(*args):
     callback=deprecated_precision,
     help="Unused, deprecated, and will be removed in 2.0.0.",
 )
+@click.option(
+    "--target-aligned-pixels/--no-target-aligned-pixels",
+    default=False,
+    help="Align the output bounds based on the resolution.",
+)
+@click.option(
+    "--mem-limit",
+    type=int,
+    default=64,
+    help="Limit on memory used to perform calculations, in MB.",
+)
+@click.option(
+    "--use-highest-res/--use-first-res",
+    default=False,
+    help="Use the highest resolution of sources or the resolution of the first source argument.",
+)
 @options.creation_options
 @click.pass_context
 def merge(
@@ -49,11 +71,15 @@ def merge(
     bounds,
     res,
     resampling,
+    method,
     nodata,
     dtype,
     bidx,
     overwrite,
     precision,
+    target_aligned_pixels,
+    mem_limit,
+    use_highest_res,
     creation_options,
 ):
     """Copy valid pixels from input files to an output file.
@@ -94,6 +120,10 @@ def merge(
             dtype=dtype,
             indexes=(bidx or None),
             resampling=resampling,
+            method=method,
+            target_aligned_pixels=target_aligned_pixels,
+            mem_limit=mem_limit,
+            use_highest_res=use_highest_res,
             dst_path=output,
             dst_kwds=creation_options,
         )
