@@ -22,7 +22,7 @@ Registry of common rio CLI options.  See cligj for more options.
     --height: height of raster.  In rio-info
     -i, --invert: Invert mask created from features: In rio-mask
     -j, --geojson-mask: GeoJSON for masking raster.  In rio-mask
-    --lnglat: geograhpic coordinates of center of raster.  In rio-info
+    --lnglat: geographic coordinates of center of raster.  In rio-info
     --masked/--not-masked: read masked data from source file.
         In rio-calc, rio-info
     -m, --mode: output file mode (r, r+).  In rio-insp
@@ -79,9 +79,8 @@ def _cb_key_val(ctx, param, value):
     else:
         out = {}
         for pair in value:
-            if '=' not in pair:
-                raise click.BadParameter(
-                    "Invalid syntax for KEY=VAL arg: {}".format(pair))
+            if "=" not in pair:
+                raise click.BadParameter(f"Invalid syntax for KEY=VAL arg: {pair}")
             else:
                 k, v = pair.split('=', 1)
                 k = k.lower()
@@ -113,20 +112,18 @@ def file_in_handler(ctx, param, value):
         elif path.archive:
             if os.path.exists(path.archive) and rasterio.shutil.exists(value):
                 archive = abspath_forward_slashes(path.archive)
-                return "{}://{}!{}".format(path.scheme, archive, path.path)
+                return f"{path.scheme}://{archive}!{path.path}"
             else:
-                raise OSError(
-                    "Input archive {} does not exist".format(path.archive))
+                raise OSError(f"Input archive {path.archive} does not exist")
 
         else:
             if os.path.exists(path.path) and rasterio.shutil.exists(value):
                 return abspath_forward_slashes(path.path)
             else:
-                raise OSError(
-                    "Input file {} does not exist".format(path.path))
+                raise OSError(f"Input file {path.path} does not exist")
 
     except Exception:
-        raise click.BadParameter("{} is not a valid input file".format(value))
+        raise click.BadParameter(f"{value} is not a valid input file")
 
 
 def files_in_handler(ctx, param, value):
@@ -175,7 +172,7 @@ def nodata_handler(ctx, param, value):
             return float(value)
         except (TypeError, ValueError):
             raise click.BadParameter(
-                "{!r} is not a number".format(value), param=param, param_hint="nodata"
+                f"{value!r} is not a number", param=param, param_hint="nodata"
             )
 
 
@@ -212,8 +209,8 @@ def bounds_handler(ctx, param, value):
             return retval
         except Exception:
             raise click.BadParameter(
-                "{0!r} is not a valid bounding box representation".format(
-                    value))
+                "{!r} is not a valid bounding box representation".format(value)
+            )
     else:  # pragma: no cover
         return retval
 
@@ -222,9 +219,7 @@ def bounds_handler(ctx, param, value):
 file_in_arg = click.argument('INPUT', callback=file_in_handler)
 
 # Singular output file
-file_out_arg = click.argument(
-    'OUTPUT',
-    type=click.Path(resolve_path=True))
+file_out_arg = click.argument("OUTPUT", type=click.Path())
 
 # Multiple input files.
 files_in_arg = click.argument(
@@ -264,10 +259,13 @@ bidx_magic_opt = click.option(
     multiple=True,
     help="Indexes of input file bands.")
 
-# TODO: may be better suited to cligj
+# TODO: may be better suited to cligj?
 bounds_opt = click.option(
-    '--bounds', default=None, callback=bounds_handler,
-    help='Bounds: "left bottom right top" or "[left, bottom, right, top]".')
+    "--bounds",
+    default=None,
+    callback=bounds_handler,
+    help="Bounds: 'left bottom right top' or '[left, bottom, right, top]'.",
+)
 
 dimensions_opt = click.option(
     '--dimensions',
@@ -298,7 +296,7 @@ masked_opt = click.option(
 output_opt = click.option(
     '-o', '--output',
     default=None,
-    type=click.Path(resolve_path=True),
+    type=click.Path(),
     help="Path to output file (optional alternative to a positional arg).")
 
 resolution_opt = click.option(
@@ -321,7 +319,6 @@ creation_options = click.option(
 rgb_opt = click.option(
     '--rgb', 'photometric',
     flag_value='rgb',
-    default=False,
     help="Set RGB photometric interpretation.")
 
 overwrite_opt = click.option(
@@ -370,5 +367,49 @@ sequence_opt = click.option(
          "feature collection object.")
 
 format_opt = click.option(
-    '-f', '--format', '--driver', 'driver',
-    help="Output format driver")
+    "-f", "--format", "--driver", "driver", help="Output format driver."
+)
+
+
+def geojson_type_opt(*, allowed, default):
+    """GeoJSON output mode"""
+    def verify_geojson_type(ctx, param, value):
+        geojson_type = ctx.params.setdefault("geojson_type", {})
+        geojson_type[param.name] = value
+        if len(geojson_type) == len(allowed):
+            # We've now seen all options for geojson_type, so verify their contents.
+            specified = [
+                name.removeprefix("geojson_type_")
+                for name, value in geojson_type.items()
+                if value
+            ]
+            if len(specified) > 1:
+                names = ",".join(f"--{name}" for name in specified)
+                raise click.BadParameter(
+                    f"too many GeoJSON output formats: {names} may not be specified together"
+                )
+            ctx.params["geojson_type"] = specified[0] if specified else default
+
+    def wrapper(func):
+        options = {
+            "collection": "feature collection(s)",
+            "feature": "feature(s)",
+            "bbox": "bounding box array(s)",
+        }
+
+        for name in allowed:
+            if name not in options:
+                raise click.UsageError(f"{name} is not a valid GeoJSON output mode")
+            help_suffix = " (default)" if name == default else ""
+            opt = click.option(
+                f"--{name}",
+                f"geojson_type_{name}",
+                is_flag=True,
+                expose_value=False,
+                callback=verify_geojson_type,
+                help=f"Output as GeoJSON {options[name]}{help_suffix}",
+            )
+            func = opt(func)
+        return func
+
+    return wrapper
