@@ -25,11 +25,15 @@ from affine import Affine
 DEFAULT_SHAPE = (10, 10)
 
 
-if sys.version_info > (3,):
-    reduce = functools.reduce
+reduce = functools.reduce
+
+try:
+    have_credentials = boto3.Session().get_credentials()
+except Exception:
+    have_credentials = False
 
 credentials = pytest.mark.skipif(
-    not(boto3.Session().get_credentials()),
+    not(have_credentials),
     reason="S3 raster access requires credentials")
 
 
@@ -522,6 +526,12 @@ def path_rgb_byte_tif(data_dir):
     return os.path.join(data_dir, 'RGB.byte.tif')
 
 
+@pytest.fixture(scope='session')
+def path_srtm_hgt(data_dir):
+    """Sample SRTM HGT file"""
+    return os.path.join(data_dir, 'N10W110.hgt.zip')
+
+
 @pytest.fixture(scope='session')
 def path_rgb_lzw_byte_tif(data_dir):
     """The original RGB test fixture with LZW compression."""
@@ -629,7 +639,7 @@ def path_alpha_tif(data_dir):
 def path_zip_file(data_dir):
     """Creates ``coutwildrnp.zip`` if it does not exist and returns
     the absolute file path."""
-    path = '{}/white-gemini-iv.zip'.format(data_dir)
+    path = f"{data_dir}/white-gemini-iv.zip"
     if not os.path.exists(path):
         with zipfile.ZipFile(path, 'w') as zip:
             for filename in ['white-gemini-iv.vrt',
@@ -641,7 +651,7 @@ def path_zip_file(data_dir):
 @pytest.fixture(autouse=True)
 def set_mem_name(request, monkeypatch):
     def youyoueyedeefour():
-        return "{}-{}".format(request.node.name, uuid.uuid4())
+        return f"{request.node.name}-{uuid.uuid4()}"
     monkeypatch.setattr(rasterio._io, "uuid4", youyoueyedeefour)
 
 
@@ -654,22 +664,12 @@ class MockGeoInterface:
 # Define helpers to skip tests based on GDAL version
 gdal_version = GDALVersion.runtime()
 
+requires_gdal37 = pytest.mark.skipif(
+    not gdal_version.at_least('3.7'), reason="Requires GDAL 3.7.x"
+)
 
-requires_gdal32 = pytest.mark.skipif(
-    not gdal_version.at_least('3.2'),
-    reason="Requires GDAL 3.2.x")
-
-requires_gdal33 = pytest.mark.skipif(
-    not gdal_version.at_least('3.3'),
-    reason="Requires GDAL 3.3.x")
-
-requires_gdal35 = pytest.mark.skipif(
-    not gdal_version.at_least('3.5'),
-    reason="Requires GDAL 3.5.x")
-
-requires_gdal_lt_35 = pytest.mark.skipif(
-    gdal_version.at_least('3.5'),
-    reason="Requires GDAL before 3.5",
+requires_gdal_lt_37 = pytest.mark.skipif(
+    gdal_version.at_least('3.7'), reason="Requires GDAL before 3.7"
 )
 
 
