@@ -1,6 +1,4 @@
-import logging
 import subprocess
-import sys
 import uuid
 
 import numpy as np
@@ -12,7 +10,7 @@ import rasterio
 @pytest.fixture(scope='function')
 def tempfile():
     """A temporary filename in the GDAL '/vsimem' filesystem"""
-    return '/vsimem/{}'.format(uuid.uuid4())
+    return f"/vsimem/{uuid.uuid4()}"
 
 
 def complex_image(height, width, dtype):
