@@ -45,21 +45,19 @@ class CustomCRS:
 def test_crs_constructor_dict():
     """Can create a CRS from a dict"""
     crs = CRS({'init': 'epsg:3857'})
-    assert crs['init'] == 'epsg:3857'
     assert 'PROJCS["WGS 84 / Pseudo-Mercator"' in crs.wkt
 
 
 def test_crs_constructor_keywords():
     """Can create a CRS from keyword args, ignoring unknowns"""
+    # Note: `init="epsg:dddd"` is no longer recommended usage.
     crs = CRS(init='epsg:3857', foo='bar')
-    assert crs['init'] == 'epsg:3857'
     assert 'PROJCS["WGS 84 / Pseudo-Mercator"' in crs.wkt
 
 
 def test_crs_constructor_crs_obj():
     """Can create a CRS from a CRS obj"""
-    crs = CRS(CRS(init='epsg:3857'))
-    assert crs['init'] == 'epsg:3857'
+    crs = CRS(CRS.from_epsg(3857))
     assert 'PROJCS["WGS 84 / Pseudo-Mercator"' in crs.wkt
 
 
@@ -123,21 +121,21 @@ def test_from_proj4_json():
 
 
 def test_from_epsg():
-    crs_dict = CRS.from_epsg(4326)
-    assert crs_dict['init'].lower() == 'epsg:4326'
+    assert CRS.from_epsg(4326)._epsg == 4326
 
-    # Test with invalid EPSG code
+
+def test_from_epsg_fail():
     with pytest.raises(ValueError):
-        assert CRS.from_epsg(0)
+        CRS.from_epsg(0)
 
 
 def test_from_epsg_string():
-    crs_dict = CRS.from_string('epsg:4326')
-    assert crs_dict['init'].lower() == 'epsg:4326'
+    assert CRS.from_string("epsg:4326")._epsg == 4326
 
-    # Test with invalid EPSG code
+
+def test_from_epsg_string_fail():
     with pytest.raises(ValueError):
-        assert CRS.from_string('epsg:xyz')
+        CRS.from_string("epsg:xyz")
 
 
 def test_from_epsg_overflow():
@@ -147,12 +145,20 @@ def test_from_epsg_overflow():
 
 
 def test_from_string():
-    wgs84_crs = CRS.from_string('+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs')
-    assert wgs84_crs.to_dict() == {'init': 'epsg:4326'}
+    wgs84_crs = CRS.from_string("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
+    assert wgs84_crs.to_dict() == {"proj": "longlat", "datum": "WGS84", "no_defs": True}
 
+
+def test_from_string_2():
     # Make sure this doesn't get handled using the from_epsg() even though 'epsg' is in the string
-    epsg_init_crs = CRS.from_string('+init=epsg:26911')
-    assert epsg_init_crs.to_dict() == {'init': 'epsg:26911'}
+    epsg_init_crs = CRS.from_string("+init=epsg:26911")
+    assert epsg_init_crs.to_dict() == {
+        "proj": "utm",
+        "zone": 11,
+        "datum": "NAD83",
+        "units": "m",
+        "no_defs": True,
+    }
 
 
 @pytest.mark.parametrize('proj,expected', [({'init': 'epsg:4326'}, True), ({'init': 'epsg:3857'}, False)])
@@ -194,15 +200,6 @@ def test_equality_from_dict(epsg_code):
 
 
 def test_is_same_crs():
-    crs1 = CRS({'init': 'epsg:4326'})
-    crs2 = CRS({'init': 'epsg:3857'})
-
-    assert crs1 == crs1
-    assert crs1 != crs2
-
-    wgs84_crs = CRS.from_string('+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs')
-    assert crs1 == wgs84_crs
-
     # Make sure that same projection with different parameter are not equal
     lcc_crs1 = CRS.from_string('+lon_0=-95 +ellps=GRS80 +y_0=0 +no_defs=True +proj=lcc +x_0=0 +units=m +lat_2=77 +lat_1=49 +lat_0=0')
     lcc_crs2 = CRS.from_string('+lon_0=-95 +ellps=GRS80 +y_0=0 +no_defs=True +proj=lcc +x_0=0 +units=m +lat_2=77 +lat_1=45 +lat_0=0')
@@ -291,9 +288,7 @@ def test_epsg__no_code_available():
 def test_crs_OSR_equivalence():
     crs1 = CRS.from_string('+proj=longlat +datum=WGS84 +no_defs')
     crs2 = CRS.from_string('+proj=latlong +datum=WGS84 +no_defs')
-    crs3 = CRS({'init': 'epsg:4326'})
     assert crs1 == crs2
-    assert crs1 == crs3
 
 
 def test_crs_OSR_no_equivalence():
@@ -328,7 +323,7 @@ def test_from_wkt_invalid():
 
 
 def test_from_user_input_epsg():
-    assert 'init' in CRS.from_user_input('epsg:4326')
+    assert CRS.from_user_input("epsg:4326")._epsg == 4326
 
 
 @pytest.mark.parametrize("version", ["WKT2_2019", WktVersion.WKT2_2019])
@@ -570,6 +565,11 @@ def test_esri_auth__to_epsg():
 def test_esri_auth__to_authority():
     assert CRS.from_user_input('ESRI:54009').to_authority() == ('ESRI', '54009')
 
+def test_iau_auth__to_authority():
+    assert CRS.from_user_input('IAU_2015:49900').to_authority() == ('IAU_2015', '49900')
+
+def test_iau_from_authority__to_authority():
+    assert CRS.from_authority('IAU_2015', 49900).to_authority() == ('IAU_2015', '49900')
 
 def test_from_authority__to_authority():
     assert CRS.from_authority("EPSG", 4326).to_authority() == ("EPSG", "4326")
@@ -658,3 +658,22 @@ def test_crs_proj_json__from_string():
 
 def test_crs_compound_epsg():
     assert CRS.from_string("EPSG:4326+3855").to_wkt().startswith("COMPD")
+
+
+@pytest.mark.parametrize("crs", [CRS.from_epsg(4326), CRS.from_string("EPSG:4326")])
+def test_epsg_4326_ogc_crs84(crs):
+    """EPSG:4326 not equivalent to OGC:CRS84."""
+    assert CRS.from_string("OGC:CRS84") != crs
+
+
+def test_to_authority_x():
+    crs = CRS.from_epsg(32618)
+    assert crs.to_authority() == ("EPSG", "32618")
+
+
+def test_is_epsg_code():
+    crs = CRS.from_wkt(
+        'PROJCS["RGF93 v1 / Lambert-93",GEOGCS["RGF93 v1",DATUM["Reseau_Geodesique_Francais_1993_v1",SPHEROID["GRS 1980",6378137,298.257222101,AUTHORITY["EPSG","7019"]],AUTHORITY["EPSG","6171"]],PRIMEM["Greenwich",0,AUTHORITY["EPSG","8901"]],UNIT["degree",0.0174532925199433,AUTHORITY["EPSG","9122"]],AUTHORITY["EPSG","4171"]],PROJECTION["Lambert_Conformal_Conic_2SP"],PARAMETER["latitude_of_origin",46.5],PARAMETER["central_meridian",3],PARAMETER["standard_parallel_1",49],PARAMETER["standard_parallel_2",44],PARAMETER["false_easting",700000],PARAMETER["false_northing",6600000],UNIT["metre",1,AUTHORITY["EPSG","9001"]],AXIS["Easting",EAST],AXIS["Northing",NORTH],AUTHORITY["EPSG","2154"]]'
+    )
+    assert crs.to_epsg() == 2154
+    assert crs.is_epsg_code
