@@ -15,7 +15,7 @@ def test_gray_gray():
     assert enums.ColorInterp.gray.name == "gray"
 
 
-@pytest.mark.parametrize("resamp", enums._OverviewResampling)
+@pytest.mark.parametrize("resamp", enums.OverviewResampling)
 def test_resampling(resamp):
     """Make sure that resampling value are the same."""
     assert resamp.value == enums.Resampling[resamp.name].value
