@@ -14,7 +14,7 @@ from rasterio import _env
 from rasterio._env import del_gdal_config, get_gdal_config, set_gdal_config
 from rasterio.env import Env, defenv, delenv, getenv, setenv, ensure_env, ensure_env_credentialled
 from rasterio.env import GDALVersion, require_gdal_version
-from rasterio.errors import EnvError, RasterioIOError, GDALVersionError
+from rasterio.errors import EnvError, GDALVersionError
 from rasterio.rio.main import main_group
 from rasterio.session import AWSSession, DummySession, OSSSession, SwiftSession, AzureSession
 
@@ -93,7 +93,7 @@ def test_env_accessors(gdalenv):
 
 
 def test_env_accessors_no_env():
-    """Sould all raise an exception."""
+    """Should all raise an exception."""
     with pytest.raises(EnvError):
         delenv()
     with pytest.raises(EnvError):
@@ -441,13 +441,6 @@ def test_open_with_env(gdalenv):
             assert dataset.count == 3
 
 
-def test_skip_gtiff(gdalenv):
-    """De-register GTiff driver, verify that it will not be used."""
-    with rasterio.Env(GDAL_SKIP='GTiff'):
-        with pytest.raises(RasterioIOError):
-            rasterio.open('tests/data/RGB.byte.tif')
-
-
 @credentials
 @pytest.mark.network
 def test_s3_open_with_env(gdalenv):
@@ -620,7 +613,7 @@ def test_have_registered_drivers():
     """Ensure drivers are only registered once, otherwise each thread will
     acquire a threadlock whenever an environment is started."""
     with rasterio.Env():
-        assert rasterio.env.local._env._have_registered_drivers
+        assert rasterio._env._have_registered_drivers
 
 
 def test_gdal_cachemax():
